==> google_cloud_dataplex-0.2.0-py2.py3-none-any.whl: google/cloud/dataplex_v1/services/content_service/pagers.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import (
    Any,
    AsyncIterator,
    Awaitable,
    Callable,
    Sequence,
    Tuple,
    Optional,
    Iterator,
)

from google.cloud.dataplex_v1.types import analyze
from google.cloud.dataplex_v1.types import content


class ListContentPager:
    """A pager for iterating through ``list_content`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.dataplex_v1.types.ListContentResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``content`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListContent`` requests and continue to iterate
    through the ``content`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.dataplex_v1.types.ListContentResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., content.ListContentResponse],
        request: content.ListContentRequest,
        response: content.ListContentResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.dataplex_v1.types.ListContentRequest):
                The initial request object.
            response (google.cloud.dataplex_v1.types.ListContentResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = content.ListContentRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[content.ListContentResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[analyze.Content]:
        for page in self.pages:
            yield from page.content

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListContentAsyncPager:
    """A pager for iterating through ``list_content`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.dataplex_v1.types.ListContentResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``content`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListContent`` requests and continue to iterate
    through the ``content`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.dataplex_v1.types.ListContentResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[content.ListContentResponse]],
        request: content.ListContentRequest,
        response: content.ListContentResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.dataplex_v1.types.ListContentRequest):
                The initial request object.
            response (google.cloud.dataplex_v1.types.ListContentResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = content.ListContentRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[content.ListContentResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[analyze.Content]:
        async def async_generator():
            async for page in self.pages:
                for response in page.content:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)

==> google_cloud_dataplex-1.4.2-py2.py3-none-any.whl: google/cloud/dataplex_v1/services/content_service/pagers.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import (
    Any,
    AsyncIterator,
    Awaitable,
    Callable,
    Iterator,
    Optional,
    Sequence,
    Tuple,
)

from google.cloud.dataplex_v1.types import analyze, content


class ListContentPager:
    """A pager for iterating through ``list_content`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.dataplex_v1.types.ListContentResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``content`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListContent`` requests and continue to iterate
    through the ``content`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.dataplex_v1.types.ListContentResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., content.ListContentResponse],
        request: content.ListContentRequest,
        response: content.ListContentResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.dataplex_v1.types.ListContentRequest):
                The initial request object.
            response (google.cloud.dataplex_v1.types.ListContentResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = content.ListContentRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[content.ListContentResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[analyze.Content]:
        for page in self.pages:
            yield from page.content

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListContentAsyncPager:
    """A pager for iterating through ``list_content`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.dataplex_v1.types.ListContentResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``content`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListContent`` requests and continue to iterate
    through the ``content`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.dataplex_v1.types.ListContentResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[content.ListContentResponse]],
        request: content.ListContentRequest,
        response: content.ListContentResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.dataplex_v1.types.ListContentRequest):
                The initial request object.
            response (google.cloud.dataplex_v1.types.ListContentResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = content.ListContentRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[content.ListContentResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[analyze.Content]:
        async def async_generator():
            async for page in self.pages:
                for response in page.content:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
